@@ -14,7 +14,8 @@ subroutine tangent_mean_scal( x, y, xc, yc, u, r, theta, v )
   !     ,  interpolation_2d Ƿ׻.
   ! (4) nr x nt Ĥޥ顼ͤޤä, nt ʿѷ׻ mean_1d .
   ! ʾǳ nr ˤĤʿͤ.
-  use analy
+  use algebra
+  use Derivation
   use max_min
   use statistics
   use Geometry
@@ -117,7 +118,8 @@ subroutine tangent_mean_anom_scal( x, y, xc, yc, u, r, theta, v )
   ! ܥ롼ʿ̶˺ɸåͤǤк׻Ԥ.
   ! ʿѤԤäΤ, ǥȺɸкȤˤ, 
   ! tangent_mean_anom_scal_r2c .
-  use analy
+  use algebra
+  use Derivation
   use max_min
   use statistics
   use Geometry
@@ -246,8 +248,8 @@ subroutine tangent_mean_anom_scal_Cart( x, y, xc, yc, scal, r, theta, scal_anom,
         tmpr=sqrt((x(j)-xc)**2+(y(k)-yc)**2)
         call interpo_search_1d( r, tmpr, itmpr )
         if(nr>itmpr)then
-           call interpolation_1d( r(itmpr), r(itmpr+1), tmp(itmpr),  &
-  &                               tmp(itmpr+1), tmpr, tmp_anom )
+           call interpolation_1d( (/r(itmpr), r(itmpr+1)/),  &
+  &                               (/tmp(itmpr), tmp(itmpr+1)/), tmpr, tmp_anom )
            scal_anom(j,k)=scal(j,k)-tmp_anom
         else
            scal_anom(j,k)=undeff
@@ -274,7 +276,8 @@ subroutine tangent_mean_vec( charc, x, y, xc, yc, u1, u2, r, theta, v )
   !     . Ʊ롼濴εΥǳä v ʬΤ.
   ! (4) nr x nt Ĥʬͤޤä, nt ʿѷ׻ mean_1d .
   ! ʾǳ nr ˤĤʿͤ.
-  use analy
+  use algebra
+  use Derivation
   use max_min
   use statistics
   use Geometry
@@ -423,7 +426,8 @@ subroutine tangent_mean_anom_vec( charc, x, y, xc, yc, u1, u2, r, theta, v )
   !     . Ʊ롼濴εΥǳä v ʬΤ.
   ! (4) nr x nt Ĥʬͤޤä, nt ʿѷ׻ mean_1d .
   ! ʾǳ nr ˤĤʿͤ.
-  use analy
+  use algebra
+  use Derivation
   use max_min
   use statistics
   use Geometry
@@ -560,7 +564,8 @@ end subroutine tangent_mean_anom_vec
 subroutine tangent_mean_turb( signal, r, z, u, v, w, rho, nuh, nuv, val, undef, sfctau )
 !  ʿѤήեå׻.
 !  ʿѤƤΤ, tau_{*2} ʬ (\theta ʬʬ) ϴޤޤʤ.
-  use analy
+  use algebra
+  use Derivation
   implicit none
   character(1) :: signal  ! ɸϤβܤήʬȽꤹ.
                   ! [1] = ɸˤ radial ɸʬ ( vr ʬ)
@@ -643,7 +648,8 @@ end subroutine
 
 subroutine tangent_mean_Reynolds( signal, r, z, u, v, w, rho, nuh, nuv, val, undef, sfctau )
 ! ɸϤˤ쥤Υ륺ϥƥ󥽥׻.
-  use analy
+  use algebra
+  use Derivation
   implicit none
   character(2) :: signal  ! ׻ƥ󥽥ʬ.
                   ! ['11', '22', '33'] = 줾гѥƥ󥽥ʬ
@@ -831,7 +837,8 @@ end subroutine
 
 subroutine tangent_mean_deform( signal, r, z, u, v, w, val, undef )
 ! ǥȺɸϤˤѷ®٥ƥ󥽥׻.
-  use analy
+  use algebra
+  use Derivation
   implicit none
   character(2) :: signal  ! ׻ƥ󥽥ʬ.
                   ! ['11', '22', '33'] = 줾гѥƥ󥽥ʬ
@@ -938,5 +945,243 @@ end subroutine
 !--------------------------------------------------------------
 !--------------------------------------------------------------
 
+subroutine hydro_grad_eqb( r, z, coril, v, pres_s, rho_s, pres, rho, error )
+!  ǥ󥰤ȼоήϳءʿվη׻.
+  use Thermo_Const
+  use Phys_Const
+  use algebra
+  use Derivation
+  implicit none
+  real, intent(in) :: r(:)  ! ưºɸ [m]
+  real, intent(in) :: z(:)  ! ľɸ [m]
+  real, intent(in) :: coril(size(r),size(z))  ! ꥪѥ᡼ [/s]
+  real, intent(in) :: v(size(r),size(z))  ! оή [m/s]
+  real, intent(in) :: pres_s(size(z))  ! ǥ󥰤ε [Pa]
+  real, intent(in) :: rho_s(size(z))  ! ǥ󥰤̩ [kg/m^3]
+  real, intent(in), optional :: error  ! 졼μ«
+                    ! default = 1.0e-5
+  real, intent(inout) :: pres(size(r),size(z))  ! ʿվε [Pa]
+  real, intent(inout) :: rho(size(r),size(z))  ! ʿվ̩ [kg/m^3]
+  real :: old_pres(size(r),size(z)), old_rho(size(r),size(z))
+  integer :: nr, nz
+  integer :: i, j, k
+  real :: err, err_tmp, err_max
 
-end module
+  nr=size(r)
+  nz=size(z)
+
+  if(present(error))then
+     err_max=error
+  else
+     err_max=1.0e-5
+  end if
+
+!-- ʲǳƹ٤ˤ, ̩٤ϰǤȤƷʿդ鵤׻,
+!-- ͤѤϳʿդ̩٤. eps ʲˤʤޤǷ֤.
+!--  2 ȥǥ󥰤.
+  do i=1,nz
+     old_pres(nr,i)=pres_s(i)
+  end do
+!-- ̩٤ˤĤƤ, ʿ̰ͤ
+  do j=1,nz
+     do i=1,nr
+        old_rho(i,j)=rho_s(j)
+     end do
+  end do
+
+!-- ʲǥ졼󳫻.
+  err=err_max
+
+  do while(err>=err_max)
+     err=0.0
+!-- ʿդ鰵Ͼ׻
+     do j=1,nz
+        call grad_wind_pres( r, coril(:,j), v(:,j), old_rho(:,j), r(nr), old_pres(nr,j), pres(:,j) )
+     end do
+
+!-- ϳʿդ̩پ
+     do i=1,nr
+        call grad_1d( z, pres(i,:), rho(i,:) )
+        do j=1,nz
+if(i==1)then
+write(*,*) "#### pres", pres(i,j), rho(i,j)
+end if
+           rho(i,j)=-rho(i,j)/g  ! ϳؤμ, dp/dz=-g*rho ǤΤ
+        end do
+     end do
+
+!-- ̩پμ«׻
+     do j=1,nz
+        do i=1,nr
+           if(rho(i,j)==0.0)then
+              err_tmp=abs(old_rho(i,j)-rho(i,j))/abs(old_rho(i,j))
+           else
+              err_tmp=abs(old_rho(i,j)-rho(i,j))/abs(old_rho(i,j))
+           end if
+
+!-- ι
+           if(err<=err_tmp)then
+              err=err_tmp
+           end if
+
+           old_rho(i,j)=rho(i,j)
+           old_pres(i,j)=pres(i,j)
+
+        end do
+     end do
+
+  end do
+
+end subroutine
+
+!--------------------------------------------------------------
+!--------------------------------------------------------------
+
+subroutine grad_wind_pres( r, coril, v, rho, r_ref, p_ref, pres )
+!  ʿվ׻.
+  use Algebra
+  implicit none
+  real, intent(in) :: r(:)  ! r ΰֺɸ [m]
+  real, intent(in) :: coril(size(r))  ! ꥪѥ᡼ [/s]
+  real, intent(in) :: v(size(r))  ! r ΰֺɸ [m]
+  real, intent(in) :: rho(size(r))  ! ̩ [kg/m^3]
+  real, intent(in) :: r_ref  ! ʬȤʤֺɸ [m]
+  real, intent(in) :: p_ref  ! r_ref Ǥε (ʬ) [Pa]
+  real, intent(inout) :: pres(size(r))  ! ʿդǤε [Pa]
+  integer :: i, nr
+  real :: grad(size(r))
+
+  nr=size(r)
+
+  do i=1,nr
+     if(r(i)/=0.0)then
+        grad(i)=rho(i)*(v(i)*v(i)/r(i)+coril(i)*v(i))
+     else
+        grad(i)=0.0
+     end if
+  end do
+
+  do i=1,nr
+     if(r(i)<r_ref)then
+        call rectangle_int( r, grad, r(i), r_ref, pres(i) )
+        pres(i)=p_ref-pres(i)
+     else
+        if(r(i)>r_ref)then
+           call rectangle_int( r, grad, r_ref, r(i), pres(i) )
+           pres(i)=p_ref+pres(i)
+        else
+           pres(i)=p_ref
+        end if
+     end if
+  end do
+
+end subroutine
+
+
+
+
+!subroutine Rangular_moment(xp,yp,x,y,u,v,mome)
+! Ǥդޤгѱư̤׻롼
+!
+!  3 ٥ȥǷ׻뤬, ݳؤǤ 3 ̤Ϥޤפʤ
+! ǤȤȽǤ, žޤγѱưʬΤߤ
+! ׻뤳ȤˤƤ.
+!
+! Ū濴濴˱ľޤγѱư̤׻뤳ȤŪȤ.
+!
+! $$M=rv,\quad r=濴εΥ, \quad v=®Ʊ̳ʬ$$
+!
+! ֤®˰٤ѴͿ, Ǥμžޤγѱư̤
+! ׻뤳Ȥǽ.
+! ٥ȥγѷ׻롼 vec_prod Ѥ뤳ȤǶ˺ɸǤ׻ǽ.
+!  use algebra
+!  implicit none
+!  real, intent(in) :: x(:)  ! x ΰֺɸ
+!  real, intent(in) :: y(:)  ! y ΰֺɸ
+!  real, intent(in) :: xp  ! ž x ֺɸ
+!  real, intent(in) :: yp  ! ž y ֺɸ
+!  real, intent(in) :: u(size(x),size(y))  !  i,j Ǥ® 1 ʬ
+!  real, intent(in) :: v(size(x),size(y))  !  i,j Ǥ® 1 ʬ
+!  real, intent(inout) :: mome(size(x),size(y))  ! žޤгѱư
+!  real :: xxp(size(x),size(y),1)  ! x,y,xp,yp ׻濴ΰ֥٥ȥ x ʬ
+!  real :: yyp(size(x),size(y),1)  ! x,y,xp,yp ׻濴ΰ֥٥ȥ y ʬ
+!  integer :: i, j, nx, ny
+!  real :: tmp(size(x),size(y),1)
+!
+!  nx=size(x)
+!  ny=size(y)
+!
+!!$omp parallel do shared(xxp,yyp,x,y,xp,yp) private(i,j)
+!  do j=1,ny
+!     do i=1,nx
+!        xxp(i,j,1)=x(i)-xp
+!        yyp(i,j,1)=y(j)-yp
+!     end do
+!  end do
+!!$omp end parallel do
+!
+!  tmp=0.0
+!  call vec_prod(xxp,yyp,tmp,u,v,tmp,tmp,tmp,mome)
+!
+!end subroutine Rangular_moment
+!
+!
+!subroutine Aangular_moment(xp,yp,x,y,u,v,f,mome)
+!! Ǥդޤгѱư̤׻롼
+!!
+!! Ū濴濴˱ľޤγѱư̤׻뤳ȤŪȤ.
+!!
+!! $$M=rv+\dfrac{fr^2}{2} ,\quad r=濴εΥ, \quad v=®Ʊ̳ʬ$$
+!!
+!! ֤®˰٤ѴͿ, Ǥμžޤγѱư̤
+!! ׻뤳Ȥǽ.
+!!
+!! ٥ȥγѷ׻롼 vec_prod Ѥ뤳ȤǶ˺ɸǤ׻ǽ.
+!  use algebra
+!  implicit none
+!  real, intent(in) :: x(:)  ! x ΰֺɸ
+!  real, intent(in) :: y(:)  ! y ΰֺɸ
+!  real, intent(in) :: xp  ! ž x ֺɸ
+!  real, intent(in) :: yp  ! ž y ֺɸ
+!  real, intent(in) :: u(size(x),size(y))  !  i,j Ǥ® 1 ʬ
+!  real, intent(in) :: v(size(x),size(y))  !  i,j Ǥ® 1 ʬ
+!  real, intent(in) :: f(size(x),size(y))  !  i,j ǤΥꥪѥ᡼
+!  real, intent(inout) :: mome(size(x),size(y))  ! žޤгѱư
+!  real :: xxp(size(x),size(y),1)  ! x,y,xp,yp ׻濴ΰ֥٥ȥ x ʬ
+!  real :: yyp(size(x),size(y),1)  ! x,y,xp,yp ׻濴ΰ֥٥ȥ y ʬ
+!  integer :: i, j, nx, ny
+!  real :: tmp(size(x),size(y),1), rp(size(x),size(y)), tmp1(1)
+!
+!  nx=size(x)
+!  ny=size(y)
+!
+!!$omp parallel do shared(xxp,yyp,x,y,xp,yp) private(i,j)
+!  do j=1,ny
+!     do i=1,nx
+!        xxp(i,j,1)=x(i)-xp
+!        yyp(i,j,1)=y(j)-yp
+!     end do
+!  end do
+!!$omp end parallel do
+!
+!  tmp=0.0
+!  call vec_prod(xxp,yyp,tmp,u,v,tmp,tmp,tmp,mome)
+!  call radius(xp,yp,0.0,x,y,tmp1,rp)
+!
+!!$omp parallel do shared(mome,f,rp) private(i,j)
+!  do j=1,ny
+!     do i=1,nx
+!        mome(i,j)=mome(i,j)+0.5*f(i,j)*rp(i,j)**2
+!     end do
+!  end do
+!!$omp end parallel do
+!
+!end subroutine Aangular_moment
+
+!-----------------------------------------
+!-----------------------------------------
+
+!-----------------------------------------
+!-----------------------------------------
+
+end module typhoon_analy
