@@ -255,39 +255,39 @@ subroutine read_file_gtool3_header_c( fname, header, val )
   integer, parameter :: vnum=43
   character(16) :: raw_dat(64)
   character(16) :: tmpc
-  character(10) :: signc(vnum)
+  character(6) :: signc(vnum)
   integer :: signi(vnum)
   integer :: i, j
 
-  signc=(/'dset',  &
-  &       'item',  &
-  &       'edit1',  &
-  &       'edit2',  &
-  &       'edit3',  &
-  &       'edit4',  &
-  &       'edit5',  &
-  &       'edit6',  &
-  &       'edit7',  &
-  &       'edit8',  &
-  &       'titl1',  &
-  &       'titl2',  &
-  &       'uni',  &
-  &       'ettl1',  &
-  &       'ettl2',  &
-  &       'ettl3',  &
-  &       'ettl4',  &
-  &       'ettl5',  &
-  &       'ettl6',  &
-  &       'ettl7',  &
-  &       'ettl8',  &
-  &       'date',  &
-  &       'utim',  &
-  &       'aitm1',  &
-  &       'aitm2',  &
-  &       'aitm3',  &
-  &       'dfmt',  &
-  &       'coptn',  &
-  &       'utim2',  &
+  signc=(/'dset  ',  &
+  &       'item  ',  &
+  &       'edit1 ',  &
+  &       'edit2 ',  &
+  &       'edit3 ',  &
+  &       'edit4 ',  &
+  &       'edit5 ',  &
+  &       'edit6 ',  &
+  &       'edit7 ',  &
+  &       'edit8 ',  &
+  &       'titl1 ',  &
+  &       'titl2 ',  &
+  &       'uni   ',  &
+  &       'ettl1 ',  &
+  &       'ettl2 ',  &
+  &       'ettl3 ',  &
+  &       'ettl4 ',  &
+  &       'ettl5 ',  &
+  &       'ettl6 ',  &
+  &       'ettl7 ',  &
+  &       'ettl8 ',  &
+  &       'date  ',  &
+  &       'utim  ',  &
+  &       'aitm1 ',  &
+  &       'aitm2 ',  &
+  &       'aitm3 ',  &
+  &       'dfmt  ',  &
+  &       'coptn ',  &
+  &       'utim2 ',  &
   &       'memo01',  &
   &       'memo02',  &
   &       'memo03',  &
@@ -298,10 +298,10 @@ subroutine read_file_gtool3_header_c( fname, header, val )
   &       'memo08',  &
   &       'memo09',  &
   &       'memo10',  &
-  &       'cdate',  &
-  &       'csign',  &
-  &       'mdate',  &
-  &       'msign' /)
+  &       'cdate ',  &
+  &       'csign ',  &
+  &       'mdate ',  &
+  &       'msign ' /)
 
   signi=(/2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 14, 15, 16, 17, 18, 19, 20, 21,  &
   &       22, 23, 24, 26, 27, 29, 32, 35, 38, 45, 49, 50, 51, 52, 53, 54,  &
@@ -336,25 +336,25 @@ subroutine read_file_gtool3_header_i( fname, header, val )
   integer, parameter :: vnum=15
   character(16) :: raw_dat(64)
   character(16) :: tmpc
-  character(10) :: signc(vnum)
+  character(6) :: signc(vnum)
   integer :: signi(vnum)
   integer :: i, j
 
-  signc=(/'idfm',  &
-  &       'fnum',  &
-  &       'dnum',  &
-  &       'time',  &
-  &       'tdur',  &
-  &       'astr1',  &
-  &       'aend1',  &
-  &       'astr2',  &
-  &       'aend2',  &
-  &       'astr3',  &
-  &       'aend3',  &
-  &       'styp',  &
-  &       'ioptn',  &
-  &       'time2',  &
-  &       'size' /)
+  signc=(/'idfm  ',  &
+  &       'fnum  ',  &
+  &       'dnum  ',  &
+  &       'time  ',  &
+  &       'tdur  ',  &
+  &       'astr1 ',  &
+  &       'aend1 ',  &
+  &       'astr2 ',  &
+  &       'aend2 ',  &
+  &       'astr3 ',  &
+  &       'aend3 ',  &
+  &       'styp  ',  &
+  &       'ioptn ',  &
+  &       'time2 ',  &
+  &       'size  ' /)
 
   signi=(/1, 12, 13, 25, 28, 30, 31, 33, 34, 36, 37, 44, 46, 48, 64 /)
 
@@ -391,12 +391,12 @@ subroutine read_file_gtool3_header_r( fname, header, val )
   integer :: signi(vnum)
   integer :: i, j
 
-  signc=(/'miss',  &
-  &       'dmin',  &
-  &       'dmax',  &
-  &       'divs',  &
-  &       'divl',  &
-  &       'roptn' /)
+  signc=(/'miss  ',  &
+  &       'dmin  ',  &
+  &       'dmax  ',  &
+  &       'divs  ',  &
+  &       'divl  ',  &
+  &       'roptn ' /)
 
   signi=(/39, 40, 41, 42, 43, 47 /)
 
@@ -481,4 +481,43 @@ subroutine read_file_text( fname, nx, ny, val, skip, forma )
 
 end subroutine
 
+!-----------------------------------
+!-----------------------------------
+
+subroutine read_mgdsst( fname, sst )
+! mgdsst ǡɤ߹िΥ롼
+! ɤ߹ѥǡ 1440 x 720 Ǹ.
+! , mgdsst ΥեޥåȤ餯ΤǤ.
+  implicit none
+  integer, parameter :: nx=1440  ! γʻ
+  integer, parameter :: ny=720  ! γʻ
+  character(*), intent(in) :: fname  ! ɤ߹ mgdsst 롼
+  real, intent(inout), dimension(nx,ny) :: sst  ! ɤ߹ SST ǡ [K].
+                              ! , 999.0 ̤, 888.0 ɹ.
+  character(3), dimension(nx,ny) :: sstc
+  character(10) :: formatt
+  integer :: i, j, k
+
+  formatt='(1440a3)'
+
+  call read_file_text( trim(fname), nx, ny, sstc, skip=1, forma=trim(formatt))
+!  open(unit=12,file=trim(dat_list(i)),status='old')
+!     read(12,*) sstc(1,1)
+  do k=1,ny
+!     read(12,formatt) (sstc(j,k),j=1,nx)
+     do j=1,nx
+        if(sstc(j,k)=='888'.or.sstc(j,k)=='999')then
+           sst(j,ny-k+1)=999.0
+        else
+           read(sstc(j,k),*) sst(j,ny-k+1)
+           sst(j,ny-k+1)=sst(j,ny-k+1)/10.0+273.15
+!           write(*,*) j,k,sstc(j,k),sst(j,k)
+        end if
+!        tmp(j,ny-k+1)=sst(j,k)
+!        sst(j,k)=tmp(j,k)
+     end do
+  end do
+
+end subroutine
+
 end module
